from .athena_client import AthenaClient as AthenaClient
from .cloudwatch_client import CloudWatchClient as CloudWatchClient
from .codeartifact_client import CodeArtifactClient as CodeArtifactClient
from .codeartifact_format import CodeArtifactFormat as CodeArtifactFormat
from .cost_explorer_client import CostExplorerClient as CostExplorerClient
from .ec2_client import EC2Client as EC2Client
from .elasticache_client import ElastiCacheClient as ElastiCacheClient
from .msk_client import MSKClient as MSKClient
from .organizations_client import OrganizationsClient as OrganizationsClient
from .s3_client import s3Client as s3Client
from .secrets_manager_client import SecretsManagerClient as SecretsManagerClient
from .sts_client import STSClient as STSClient